@@ -49,19 +49,25 @@ def decrypt_file(file, key):
 
     os.chmod(file[:-4], 0o600)
 
-def setup_deploy_key(keypath='github_deploy_key', key_ext='.enc'):
+def setup_deploy_key(keypath='github_deploy_key', key_ext='.enc', env_name='DOCTR_DEPLOY_ENCRYPTION_KEY'):
     """
     Decrypts the deploy key and configures it with ssh
 
     The key is assumed to be encrypted as keypath + key_ext, and the
     encryption key is assumed to be set in the environment variable
-    DOCTR_DEPLOY_ENCRYPTION_KEY.
+    ``env_name``. If ``env_name`` is not set, it falls back to
+    ``DOCTR_DEPLOY_ENCRYPTION_KEY`` for backwards compatibility.
 
+    If keypath + key_ext does not exist, it falls back to
+    ``github_deploy_key.enc`` for backwards compatibility.
     """
-    key = os.environ.get("DOCTR_DEPLOY_ENCRYPTION_KEY", None)
+    key = os.environ.get(env_name, os.environ.get("DOCTR_DEPLOY_ENCRYPTION_KEY", None))
     if not key:
-        raise RuntimeError("DOCTR_DEPLOY_ENCRYPTION_KEY environment variable is not set")
+        raise RuntimeError("{env_name} or DOCTR_DEPLOY_ENCRYPTION_KEY environment variable is not set"
+            .format(env_name=env_name))
 
+    if not os.path.isfile(keypath + key_ext):
+        keypath = 'github_deploy_key'
     key_filename = os.path.basename(keypath)
     key = key.encode('utf-8')
     decrypt_file(keypath + key_ext, key)
@@ -131,10 +137,10 @@ def run(args, shell=False, exit=True):
     If exit=True, it exits on nonzero returncode. Otherwise it returns the
     returncode.
     """
-    if "DOCTR_DEPLOY_ENCRYPTION_KEY" in os.environ:
-        token = b''
-    else:
+    if "GH_TOKEN" in os.environ:
         token = get_token()
+    else:
+        token = b''
 
     if not shell:
         command = ' '.join(map(shlex.quote, args))
@@ -177,7 +183,10 @@ def get_travis_branch():
     else:
         return os.environ.get("TRAVIS_BRANCH", "")
 
-def setup_GitHub_push(deploy_repo, auth_type='deploy_key', full_key_path='github_deploy_key.enc', require_master=None, branch_whitelist=None, deploy_branch='gh-pages'):
+def setup_GitHub_push(deploy_repo, *, auth_type='deploy_key',
+    full_key_path='github_deploy_key.enc', require_master=None,
+    branch_whitelist=None, deploy_branch='gh-pages',
+    env_name='DOCTR_DEPLOY_ENCRYPTION_KEY', build_tags=False):
     """
     Setup the remote to push to GitHub (to be run on Travis).
 
@@ -189,6 +198,8 @@ def setup_GitHub_push(deploy_repo, auth_type='deploy_key', full_key_path='github
 
     For ``auth_type='deploy_key'``, this sets up the remote with ssh access.
     """
+    # Set to the name of the tag for tag builds
+    TRAVIS_TAG = os.environ.get("TRAVIS_TAG", "")
 
     if not branch_whitelist:
         branch_whitelist={'master'}
@@ -206,8 +217,12 @@ def setup_GitHub_push(deploy_repo, auth_type='deploy_key', full_key_path='github
     TRAVIS_BRANCH = os.environ.get("TRAVIS_BRANCH", "")
     TRAVIS_PULL_REQUEST = os.environ.get("TRAVIS_PULL_REQUEST", "")
 
-    canpush = determine_push_rights(branch_whitelist, TRAVIS_BRANCH,
-                                    TRAVIS_PULL_REQUEST)
+    canpush = determine_push_rights(
+        branch_whitelist=branch_whitelist,
+        TRAVIS_BRANCH=TRAVIS_BRANCH,
+        TRAVIS_PULL_REQUEST=TRAVIS_PULL_REQUEST,
+        TRAVIS_TAG=TRAVIS_TAG,
+        build_tags=build_tags)
 
     print("Setting git attributes")
     set_git_user_email()
@@ -226,7 +241,7 @@ def setup_GitHub_push(deploy_repo, auth_type='deploy_key', full_key_path='github
         else:
             keypath, key_ext = full_key_path.rsplit('.', 1)
             key_ext = '.' + key_ext
-            setup_deploy_key(keypath=keypath, key_ext=key_ext)
+            setup_deploy_key(keypath=keypath, key_ext=key_ext, env_name=env_name)
             run(['git', 'remote', 'add', 'doctr_remote',
                 'git@github.com:{deploy_repo}.git'.format(deploy_repo=deploy_repo)])
     else:
@@ -434,6 +449,9 @@ def commit_docs(*, added, removed):
     TRAVIS_COMMIT = os.environ.get("TRAVIS_COMMIT", "<unknown>")
     TRAVIS_REPO_SLUG = os.environ.get("TRAVIS_REPO_SLUG", "<unknown>")
     TRAVIS_JOB_ID = os.environ.get("TRAVIS_JOB_ID", "")
+    TRAVIS_TAG = os.environ.get("TRAVIS_TAG", "")
+    branch = "tag" if TRAVIS_TAG else "branch"
+
     DOCTR_COMMAND = ' '.join(map(shlex.quote, sys.argv))
 
     for f in added:
@@ -445,7 +463,7 @@ def commit_docs(*, added, removed):
 Update docs after building Travis build {TRAVIS_BUILD_NUMBER} of
 {TRAVIS_REPO_SLUG}
 
-The docs were built from the branch '{TRAVIS_BRANCH}' against the commit
+The docs were built from the {branch} '{TRAVIS_BRANCH}' against the commit
 {TRAVIS_COMMIT}.
 
 The Travis build that generated this commit is at
@@ -455,6 +473,7 @@ The doctr command that was run is
 
     {DOCTR_COMMAND}
 """.format(
+    branch=branch,
     TRAVIS_BUILD_NUMBER=TRAVIS_BUILD_NUMBER,
     TRAVIS_BRANCH=TRAVIS_BRANCH,
     TRAVIS_COMMIT=TRAVIS_COMMIT,
@@ -497,12 +516,18 @@ def push_docs(deploy_branch='gh-pages', retries=3):
             return
     sys.exit("Giving up...")
 
-def determine_push_rights(branch_whitelist, TRAVIS_BRANCH, TRAVIS_PULL_REQUEST):
+def determine_push_rights(*, branch_whitelist, TRAVIS_BRANCH,
+    TRAVIS_PULL_REQUEST, TRAVIS_TAG, build_tags):
     """Check if Travis is running on ``master`` (or a whitelisted branch) to
     determine if we can/should push the docs to the deploy repo
     """
     canpush = True
 
+    if TRAVIS_TAG:
+        if not build_tags:
+            print("The docs are not pushed on tag builds. To push on future tag builds, use --build-tags")
+        return build_tags
+
     if not any([re.compile(x).match(TRAVIS_BRANCH) for x in branch_whitelist]):
         print("The docs are only pushed to gh-pages from master. To allow pushing from "
         "a non-master branch, use the --no-require-master flag", file=sys.stderr)
